persona-integration
#############################

.. note::

  This README was auto-generated. Maintainer: please review its contents and
  update all relevant sections. Instructions to you are marked with
  "PLACEHOLDER" or "TODO". Update or remove those sections, and remove this
  note when you are done.

|pypi-badge| |ci-badge| |codecov-badge| |doc-badge| |pyversions-badge|
|license-badge| |status-badge|

Purpose
*******

This repo contains the backend plugin that implements the Persona integration to be used for id verification.

TODO: The ``README.rst`` file should start with a brief description of the repository and its purpose.
Describe your repo for the audience you intend it for.

Getting Started with Development
********************************

Add real content to describe how to deploy the component, and where the documentation is.
Deploying
*********

TODO: How can a new user go about deploying this component? Is it just a few
commands? Is there a larger how-to that should be linked here?

Add real content to describe how to deploy the component, and where the documentation is.
Getting Help
************

Documentation
=============

PLACEHOLDER: Start by going through `the documentation`_.  If you need more help see below.

.. _the documentation: https://docs.openedx.org/projects/persona-integration

(TODO: `Set up documentation <https://openedx.atlassian.net/wiki/spaces/DOC/pages/21627535/Publish+Documentation+on+Read+the+Docs>`_)

More Help
=========

Write a paragraph explaining how people can get help with the repo.  Here are some possibilities:

“This repo is available for you to use, but we are unable to provide help.”

“If you are interested in using this repo, contact <PERSON>@2u.com, and we will see what we can do.”

License
*******

The code in this repository is licensed under the AGPL 3.0 unless
otherwise noted.

Please see `LICENSE.txt <LICENSE.txt>`_ for details.

Contributing
************

This repo is not currently accepting contributions.

The Open edX Code of Conduct
****************************

All community members are expected to follow the `Open edX Code of Conduct`_.

.. _Open edX Code of Conduct: https://openedx.org/code-of-conduct/

Reporting Security Issues
*************************

Please do not report security issues in public. Please email security@edx.org.

.. |pypi-badge| image:: https://img.shields.io/pypi/v/persona-integration.svg
    :target: https://pypi.python.org/pypi/persona-integration/
    :alt: PyPI

.. |ci-badge| image:: https://github.com/edx/persona-integration/workflows/Python%20CI/badge.svg?branch=main
    :target: https://github.com/edx/persona-integration/actions
    :alt: CI

.. |codecov-badge| image:: https://codecov.io/github/edx/persona-integration/coverage.svg?branch=main
    :target: https://codecov.io/github/edx/persona-integration?branch=main
    :alt: Codecov

.. |doc-badge| image:: https://readthedocs.org/projects/persona-integration/badge/?version=latest
    :target: https://docs.openedx.org/projects/persona-integration
    :alt: Documentation

.. |pyversions-badge| image:: https://img.shields.io/pypi/pyversions/persona-integration.svg
    :target: https://pypi.python.org/pypi/persona-integration/
    :alt: Supported Python versions

.. |license-badge| image:: https://img.shields.io/github/license/edx/persona-integration.svg
    :target: https://github.com/edx/persona-integration/blob/main/LICENSE.txt
    :alt: License

.. TODO: Choose one of the statuses below and remove the other status-badge lines.
.. |status-badge| image:: https://img.shields.io/badge/Status-Experimental-yellow
.. .. |status-badge| image:: https://img.shields.io/badge/Status-Maintained-brightgreen
.. .. |status-badge| image:: https://img.shields.io/badge/Status-Deprecated-orange
.. .. |status-badge| image:: https://img.shields.io/badge/Status-Unsupported-red
